

Parom = {};

function Parom.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations); 
end;

function Parom:load(xmlFile)	

	local LeftJointXNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.LeftJoint#index"));
    if LeftJointXNode ~= nil then
        self.LeftJoint = {};
        self.LeftJoint.node = LeftJointXNode;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.LeftJoint#minRot"));
        self.LeftJoint.minRot = {};
        self.LeftJoint.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.LeftJoint.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.LeftJoint.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.LeftJoint#maxRot"));
        self.LeftJoint.maxRot = {};
        self.LeftJoint.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.LeftJoint.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.LeftJoint.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.LeftJoint.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.LeftJoint#rotTime"), 2)*1000;
        self.LeftJoint.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.LeftJoint#touchRotLimit"), 10));
    end;
	local RightJointXNode = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.RightJoint#index"));
    if RightJointXNode ~= nil then
        self.RightJoint = {};
        self.RightJoint.node = RightJointXNode;
        local x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.RightJoint#minRot"));
        self.RightJoint.minRot = {};
        self.RightJoint.minRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.RightJoint.minRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.RightJoint.minRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        x, y, z = Utils.getVectorFromString(getXMLString(xmlFile, "vehicle.RightJoint#maxRot"));
        self.RightJoint.maxRot = {};
        self.RightJoint.maxRot[1] = Utils.degToRad(Utils.getNoNil(x, 0));
        self.RightJoint.maxRot[2] = Utils.degToRad(Utils.getNoNil(y, 0));
        self.RightJoint.maxRot[3] = Utils.degToRad(Utils.getNoNil(z, 0));

        self.RightJoint.rotTime = Utils.getNoNil(getXMLString(xmlFile, "vehicle.RightJoint#rotTime"), 2)*1000;
        self.RightJoint.touchRotLimit = Utils.degToRad(Utils.getNoNil(getXMLString(xmlFile, "vehicle.RightJoint#touchRotLimit"), 10));
    end;	

	
	local hydraulicsCount = Utils.getNoNil(getXMLInt(xmlFile, "vehicle.hydraulics#count"), 0);	
	self.hydraulics = {};	
	for i=1, hydraulicsCount do
		local hydraulicName = string.format("vehicle.hydraulics.hydraulic%d", i);		
		self.hydraulics[i] = {};		
		self.hydraulics[i].node = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#index"));
		self.hydraulics[i].punch = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#punch"));
		self.hydraulics[i].translationPunch = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#punchFixpoint"));
		self.hydraulics[i].fixPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, hydraulicName .. "#fixpoint"));	
		if self.hydraulics[i].punch ~= nil then
			local ax, ay, az = getWorldTranslation(self.hydraulics[i].punch);
			local bx, by, bz = getWorldTranslation(self.hydraulics[i].translationPunch);
			self.hydraulics[i].punchDistance = Utils.vector3Length(ax-bx, ay-by, az-bz);
		end;
		self.hydraulics[i].doScale = Utils.getNoNil(getXMLBool(xmlFile, hydraulicName .. "#doScale"), false);
	end;

	
	self.CarrierIsDown = false;
	self.RightJointMin = true;
	self.LeftJointMin = true;
end;

function Parom:delete()

end;

function Parom:mouseEvent(posX, posY, isDown, isUp, button)
end;

function Parom:keyEvent(unicode, sym, modifier, isDown)
end;

function Parom:update(dt)	
		if self.isActive then		

			if InputBinding.isPressed(InputBinding.LEFTSUPPORTON)  then
				self.LeftJointMax = true;												
			else
				self.LeftJointMax = false;				
			end;
			if InputBinding.isPressed(InputBinding.LEFTSUPPORTOFF)  then
				self.LeftJointMin = true;												
			else
				self.LeftJointMin = false;				
			end;
			if InputBinding.isPressed(InputBinding.RIGHTSUPPORTON)  then
				self.RightJointMax = true;												
			else
				self.RightJointMax = false;				
			end;
			if InputBinding.isPressed(InputBinding.RIGHTSUPPORTOFF)  then
				self.RightJointMin = true;												
			else
				self.RightJointMin = false;				
			end;			
			
			local doRotate = self.RightJointMax or self.RightJointMin
			if self.RightJoint ~= nil and doRotate then
				local x, y, z = getRotation(self.componentJoints[2].jointNode);
				local rot = {x,y,z};
				local newRot = Utils.getMovedLimitedValues(rot, self.RightJoint.maxRot, self.RightJoint.minRot, 3, self.RightJoint.rotTime, dt, not self.RightJointMax);
				setRotation(self.componentJoints[2].jointNode,unpack(newRot));
			end;			
			local doRotate = self.LeftJointMax or self.LeftJointMin
			if self.LeftJoint ~= nil and doRotate then
				local x, y, z = getRotation(self.componentJoints[1].jointNode);
				local rot = {x,y,z};
				local newRot = Utils.getMovedLimitedValues(rot, self.LeftJoint.maxRot, self.LeftJoint.minRot, 3, self.LeftJoint.rotTime, dt, not self.LeftJointMax);
				setRotation(self.componentJoints[1].jointNode,unpack(newRot));
			end;
			setJointFrame(self.componentJoints[1].jointIndex, 1,self.componentJoints[1].jointNode);
			setJointFrame(self.componentJoints[2].jointIndex, 1,self.componentJoints[2].jointNode);			
		
			for i=1, table.getn(self.hydraulics) do
				local ax, ay, az = getWorldTranslation(self.hydraulics[i].node);
				local bx, by, bz = getWorldTranslation(self.hydraulics[i].fixPoint);
				local x, y, z = worldDirectionToLocal(getParent(self.hydraulics[i].node), bx-ax, by-ay, bz-az);
			
				setDirection(self.hydraulics[i].node, x, y, z, 0, 1, 0);
				local distance = Utils.vector3Length(ax-bx, ay-by, az-bz);
				if self.hydraulics[i].doScale then
					local xScale, yScale, zScale = getScale(self.hydraulics[i].punch);
					local newScale = yScale * (distance / self.hydraulics[i].punchDistance);
					setScale(self.hydraulics[i].punch, 1, 1, newScale);
				else
					if self.hydraulics[i].punch ~= nil then
						setTranslation(self.hydraulics[i].punch, 0, 0, distance-self.hydraulics[i].punchDistance);
					else
						setDirection(self.hydraulics[i].node, x, y, z, 0, 1, 0);
					end;
				end;
			end;			
		end;	
end;

function Parom:draw()
	g_currentMission:addExtraPrintText(string.format("NosSupport Open/Close  %s/%s:", InputBinding.getKeyNamesOfDigitalAction(InputBinding.LEFTSUPPORTOFF), InputBinding.getKeyNamesOfDigitalAction(InputBinding.LEFTSUPPORTON)));
	g_currentMission:addExtraPrintText(string.format("KormaSupport Open/Close  %s/%s:", InputBinding.getKeyNamesOfDigitalAction(InputBinding.RIGHTSUPPORTOFF), InputBinding.getKeyNamesOfDigitalAction(InputBinding.RIGHTSUPPORTON)));		
end;

function Parom:onDetach()

end;

function Parom:onAttach()
end; 
function Parom:onLeave()

end;

function Parom:onActivate()
end;

function Parom:onDeactivate()

end;

function Parom:CarrierWorkingTime(diffTime)

end; 



